@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import json
 from enum import Enum
+from typing import List
 
 from qqbot.core.network.http import Http, HttpStatus
 from qqbot.core.network.url import get_url, APIConstant
@@ -9,20 +10,24 @@ from qqbot.core.network.websocket.ws_session_manager import SessionManager
 from qqbot.core.util import logging
 from qqbot.core.util.json_util import JsonUtil
 from qqbot.model.audio import AudioControl
-from qqbot.model.channel import Channel
+from qqbot.model.channel import (
+    Channel,
+    ChannelResponse,
+    CreateChannelRequest,
+    PatchChannelRequest,
+)
 from qqbot.model.channel_permissions import (
     ChannelPermissions,
     ChannelPermissionsUpdateRequest,
 )
 from qqbot.model.guild import Guild
-from qqbot.model.guild_member import GuildMembersPager
+from qqbot.model.guild_member import QueryParams
 from qqbot.model.guild_role import (
     GuildRoles,
     RoleUpdateResult,
     RoleUpdateRequest,
     RoleUpdateFilter,
     RoleUpdateInfo,
-    RoleMemberRequest,
 )
 from qqbot.model.member import User, Member
 from qqbot.model.message import (
@@ -30,6 +35,7 @@ from qqbot.model.message import (
     Message,
     CreateDirectMessageRequest,
     DirectMessageGuild,
+    MessagesPager,
 )
 from qqbot.model.token import Token
 
@@ -47,7 +53,7 @@ class HandlerType(Enum):
     AUDIO_EVENT_HANDLER = 7
 
 
-def listen_events(t_token: Token, is_sandbox, *handlers: Handler):
+def listen_events(t_token: Token, is_sandbox: bool, *handlers: Handler):
     """
     注册并监听频道相关事件
 
@@ -68,7 +74,7 @@ def listen_events(t_token: Token, is_sandbox, *handlers: Handler):
 class APIBase:
     timeout = 3
 
-    def __init__(self, token: Token, is_sandbox):
+    def __init__(self, token: Token, is_sandbox: bool):
         """
         API初始化信息
 
@@ -89,7 +95,7 @@ class GuildAPI(APIBase):
     频道相关接口
     """
 
-    def guild(self, guild_id) -> Guild:
+    def get_guild(self, guild_id: str) -> Guild:
         """
         获取频道信息
 
@@ -106,7 +112,7 @@ class GuildRoleAPI(APIBase):
     频道身份组相关接口
     """
 
-    def guild_roles(self, guild_id) -> GuildRoles:
+    def get_guild_roles(self, guild_id: str) -> GuildRoles:
         """
         获取频道身份组列表
 
@@ -117,8 +123,8 @@ class GuildRoleAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=GuildRoles)
 
-    def guild_role_create(
-        self, guild_id, role_info: RoleUpdateInfo
+    def create_guild_role(
+        self, guild_id: str, role_info: RoleUpdateInfo
     ) -> RoleUpdateResult:
         """
         创建频道身份组
@@ -136,8 +142,8 @@ class GuildRoleAPI(APIBase):
         response = self.http.post(url, request=serialize)
         return json.loads(response.content, object_hook=RoleUpdateResult)
 
-    def guild_role_update(
-        self, guild_id, role_id, role_info: RoleUpdateInfo
+    def update_guild_role(
+        self, guild_id: str, role_id: str, role_info: RoleUpdateInfo
     ) -> RoleUpdateResult:
         """
         修改频道身份组
@@ -158,7 +164,7 @@ class GuildRoleAPI(APIBase):
         response = self.http.patch(url, request=serialize)
         return json.loads(response.content, object_hook=RoleUpdateResult)
 
-    def guild_role_delete(self, guild_id, role_id) -> bool:
+    def delete_guild_role(self, guild_id: str, role_id: str) -> bool:
         """
         删除频道身份组
 
@@ -172,8 +178,12 @@ class GuildRoleAPI(APIBase):
         response = self.http.delete(url)
         return response.status_code == HttpStatus.ACTION_OK
 
-    def guild_role_member_add(
-        self, guild_id, role_id, user_id, role_req: RoleMemberRequest = None
+    def create_guild_role_member(
+        self,
+        guild_id: str,
+        role_id: str,
+        user_id: str,
+        role_req: Channel = None,
     ) -> bool:
         """
         增加频道身份组成员
@@ -192,8 +202,12 @@ class GuildRoleAPI(APIBase):
         response = self.http.put(url, request=JsonUtil.obj2json_serialize(role_req))
         return response.status_code == HttpStatus.ACTION_OK
 
-    def guild_role_member_delete(
-        self, guild_id, role_id, user_id, role_req: RoleMemberRequest = None
+    def delete_guild_role_member(
+        self,
+        guild_id: str,
+        role_id: str,
+        user_id: str,
+        role_req: Channel = None,
     ) -> bool:
         """
         删除频道身份组成员
@@ -218,7 +232,7 @@ class GuildMemberAPI(APIBase):
     成员相关接口，添加成员到用户组等
     """
 
-    def guild_member(self, guild_id, user_id) -> Member:
+    def get_guild_member(self, guild_id: str, user_id: str) -> Member:
         """
         获取频道指定成员
 
@@ -232,9 +246,9 @@ class GuildMemberAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=Member)
 
-    def guild_members(
-        self, guild_id, guild_member_pager: GuildMembersPager
-    ) -> [Member]:
+    def get_guild_members(
+        self, guild_id: str, guild_member_pager: QueryParams
+    ) -> List[Member]:
         """
         获取成员列表，需要申请接口权限
 
@@ -252,7 +266,7 @@ class GuildMemberAPI(APIBase):
 class ChannelAPI(APIBase):
     """子频道相关接口"""
 
-    def channel(self, channel_id) -> Channel:
+    def get_channel(self, channel_id) -> Channel:
         """
         获取子频道信息
 
@@ -265,7 +279,7 @@ class ChannelAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=Channel)
 
-    def channels(self, guild_id) -> [Channel]:
+    def get_channels(self, guild_id: str) -> List[Channel]:
         """
         获取频道下的子频道列表
 
@@ -278,11 +292,60 @@ class ChannelAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=Channel)
 
+    def create_channel(
+        self, guild_id: str, request: CreateChannelRequest
+    ) -> ChannelResponse:
+        """
+        创建子频道
+
+        :param guild_id: 频道ID
+        :param request: 创建子频道的请求对象CreateChannelRequest
+        :return ChannelResponse 对象
+        """
+        url = get_url(APIConstant.channelsURI, self.is_sandbox).format(
+            guild_id=guild_id
+        )
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = self.http.post(url, request_json)
+        return json.loads(response.content, object_hook=ChannelResponse)
+
+    def update_channel(
+        self, channel_id: str, request: PatchChannelRequest
+    ) -> ChannelResponse:
+        """
+        修改子频道
+
+        :param channel_id: 频道ID
+        :param request: PatchChannelRequest
+        :return ChannelResponse 对象
+        """
+        url = get_url(APIConstant.channelURI, self.is_sandbox).format(
+            channel_id=channel_id
+        )
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = self.http.patch(url, request_json)
+        return json.loads(response.content, object_hook=ChannelResponse)
+
+    def delete_channel(self, channel_id: str) -> ChannelResponse:
+        """
+        删除子频道
+
+        :param channel_id: 频道ID
+        :return ChannelResponse 对象
+        """
+        url = get_url(APIConstant.channelURI, self.is_sandbox).format(
+            channel_id=channel_id
+        )
+        response = self.http.delete(url)
+        return json.loads(response.content, object_hook=ChannelResponse)
+
 
 class ChannelPermissionsAPI(APIBase):
     """子频道权限相关接口"""
 
-    def channel_permissions(self, channel_id, user_id) -> ChannelPermissions:
+    def get_channel_permissions(
+        self, channel_id: str, user_id: str
+    ) -> ChannelPermissions:
         """
         获取指定子频道的权限
 
@@ -296,7 +359,7 @@ class ChannelPermissionsAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=ChannelPermissions)
 
-    def channel_permissions_update(
+    def update_channel_permissions(
         self, channel_id, user_id, request: ChannelPermissionsUpdateRequest
     ) -> bool:
         """
@@ -321,7 +384,7 @@ class ChannelPermissionsAPI(APIBase):
 class MessageAPI(APIBase):
     """消息"""
 
-    def message(self, channel_id, message_id) -> Message:
+    def get_message(self, channel_id: str, message_id: str) -> Message:
         """
         获取指定消息
 
@@ -335,7 +398,30 @@ class MessageAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=Message)
 
-    def post_message(self, channel_id, message_send: MessageSendRequest) -> Message:
+    def get_messages(self, channel_id: str, pager: MessagesPager) -> List[Message]:
+        """
+        获取指定消息列表
+
+        :param channel_id: 频道ID
+        :param pager: MessagesPager对象
+        :return: Message 对象
+        """
+        url = get_url(APIConstant.messagesURI, self.is_sandbox).format(
+            channel_id=channel_id
+        )
+        query = {}
+        if pager.limit != "":
+            query["limit"] = pager.limit
+
+        if pager.type != "" and pager.id != "":
+            query[pager.type] = pager.id
+
+        response = self.http.get(url, params=query)
+        return json.loads(response.content, object_hook=Message)
+
+    def post_message(
+        self, channel_id: str, message_send: MessageSendRequest
+    ) -> Message:
         """
         发送消息
 
@@ -357,7 +443,7 @@ class MessageAPI(APIBase):
         response = self.http.post(url, request_json)
         return json.loads(response.content, object_hook=Message)
 
-    def create_direct_message_guild(
+    def create_direct_message(
         self, create_direct_message: CreateDirectMessageRequest
     ) -> DirectMessageGuild:
         """
@@ -372,14 +458,14 @@ class MessageAPI(APIBase):
         return json.loads(response.content, object_hook=DirectMessageGuild)
 
     def post_direct_message(
-        self, guild_id, message_send: MessageSendRequest
+        self, guild_id: str, message_send: MessageSendRequest
     ) -> Message:
         """
         发送私信
 
-        :param d_msg: 创建私信频道成功后返回的对象 DirectMessageGuild
+        :param guild_id: 创建的私信频道id
         :param message_send: 发送消息的数据请求对象 MessageSendRequest
-        :return:
+        :return Message对象
         """
         url = get_url(APIConstant.dmsURI, self.is_sandbox).format(guild_id=guild_id)
         request_json = JsonUtil.obj2json_serialize(message_send)
@@ -390,7 +476,7 @@ class MessageAPI(APIBase):
 class AudioAPI(APIBase):
     """音频接口"""
 
-    def post_audio(self, channel_id, audio_control: AudioControl) -> AudioControl:
+    def post_audio(self, channel_id: str, audio_control: AudioControl) -> bool:
         """
         音频控制
 
@@ -403,7 +489,7 @@ class AudioAPI(APIBase):
         )
         request_json = JsonUtil.obj2json_serialize(audio_control)
         response = self.http.post(url, request=request_json)
-        return json.loads(response.content, object_hook=AudioControl)
+        return response.status_code == HttpStatus.ACTION_OK
 
 
 class UserAPI(APIBase):
@@ -417,7 +503,7 @@ class UserAPI(APIBase):
         response = self.http.get(url)
         return json.loads(response.content, object_hook=User)
 
-    def me_guilds(self) -> [Guild]:
+    def me_guilds(self) -> List[Guild]:
         """
         当前用户所加入的 Guild 对象列表
 
