@@ -3,9 +3,9 @@
 
 class ChannelPermissions:
     def __init__(self, data=None):
-        self.channel_id = ""
-        self.user_id = ""
-        self.permissions = ""
+        self.channel_id: str = ""
+        self.user_id: str = ""
+        self.permissions: str = ""
         if data is not None:
             self.__dict__ = data
 
